@@ -1,4 +1,4 @@
-subroutine insrt1(i,j,kj,nadj,madj,ntot,nerror)
+subroutine insrt1(i,j,kj,nadj,madj,ntot,incAdj)
 
 # Insert j into the adjacency list of i.
 # Called by insrt.
@@ -6,7 +6,8 @@ subroutine insrt1(i,j,kj,nadj,madj,ntot,nerror)
 implicit double precision(a-h,o-z)
 dimension nadj(-3:ntot,0:madj)
 
-nerror = -1
+# Initialise incAdj.
+incAdj = 0
 
 # Variable  kj is the index which j ***will***
 # have when it is inserted into the adjacency list of i in
@@ -15,9 +16,9 @@ nerror = -1
 # If the adjacency list of i had no points just stick j into the list.
 n = nadj(i,0)
 if(n==0) {
-        nadj(i,0) = 1
-        nadj(i,1) = j
-        return
+    nadj(i,0) = 1
+    nadj(i,1) = j
+    return
 }
 
 # If the adjacency list had some points, move everything ahead of the
@@ -25,12 +26,12 @@ if(n==0) {
 kk = n+1
 
 if(kk>madj) { # Watch out for over-writing!!!
-	nerror = 4
-	return
+    incAdj = 1
+    return
 }
 while(kk>kj) {
-        nadj(i,kk) = nadj(i,kk-1)
-        kk = kk-1
+    nadj(i,kk) = nadj(i,kk-1)
+    kk = kk-1
 }
 nadj(i,kj) = j
 nadj(i,0)  = n+1
